@@ -780,8 +780,8 @@ static PyObject *fparser_get_info(PyObject *self, PyObject *args) {
     UNUSED(args);
 
     struct fparser *fparser;
-    struct parser_info info;
-    struct sniff_info sniff_info;
+    struct parser_info info = {0};
+    struct sniff_info sniff_info = {0};
 
     PyObject *sniff_ntuple;
     PyObject *info_ntuple;
